==> libssh-docs-0.10.6-1-aarch64.pkg.tar.xz: usr/share/doc/libssh/html/search/all_b.js <==
var searchData=
[
  ['c_20wrapper_0',['c wrapper',['../libssh_tutor_todo.html#cpp',1,'The libssh C++ wrapper'],['../group__ssh__cpp.html',1,'The libssh C++ wrapper']]],
  ['callbacks_1',['callbacks',['../structssh__packet__callbacks__struct.html#a7a8584b3767b61599429dbb00b414c8e',1,'ssh_packet_callbacks_struct::callbacks'],['../group__libssh__callbacks.html',1,'The libssh callbacks']]],
  ['chacha20_5fpoly1305_5fkeysched_2',['chacha20_poly1305_keysched',['../structchacha20__poly1305__keysched.html',1,'']]],
  ['chacha_5fctx_3',['chacha_ctx',['../structchacha__ctx.html',1,'']]],
  ['changeptysize_4',['changePtySize',['../classssh_1_1Channel.html#a3adc48275cf34d211fb18514288f7c6f',1,'ssh::Channel']]],
  ['channel_5',['channel',['../classssh_1_1Channel.html',1,'ssh::Channel'],['../libssh_tutor_shell.html#open_channel',1,'Opening and closing a channel']]],
  ['channel_20functions_6',['The SSH channel functions',['../group__libssh__channel.html',1,'']]],
  ['channel_5fauth_5fagent_5freq_5ffunction_7',['channel_auth_agent_req_function',['../structssh__channel__callbacks__struct.html#a9790a831ce74bafb52c710bff5f28b7b',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fclose_5ffunction_8',['channel_close_function',['../structssh__channel__callbacks__struct.html#af4801e862d6c0dba76e768e85a5acd9f',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fdata_5ffunction_9',['channel_data_function',['../structssh__channel__callbacks__struct.html#a12b38a7c3b2a38493c8d841015e7e8af',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fenv_5frequest_5ffunction_10',['channel_env_request_function',['../structssh__channel__callbacks__struct.html#a5db04c0739043d36b0fc3e014f9443a5',1,'ssh_channel_callbacks_struct']]],
  ['channel_5feof_5ffunction_11',['channel_eof_function',['../structssh__channel__callbacks__struct.html#a8405b740fbbe6c48cf4a7619f1844f0d',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fexec_5frequest_5ffunction_12',['channel_exec_request_function',['../structssh__channel__callbacks__struct.html#af51c2c1fd2036141e6ca1eb7fdbcb204',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fexit_5fsignal_5ffunction_13',['channel_exit_signal_function',['../structssh__channel__callbacks__struct.html#a9da535ec706641613e8fad0ecd974da9',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fexit_5fstatus_5ffunction_14',['channel_exit_status_function',['../structssh__channel__callbacks__struct.html#a2f5987f047f0f03b63e3759f5edaa80f',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fopen_5frequest_5fauth_5fagent_5ffunction_15',['channel_open_request_auth_agent_function',['../structssh__callbacks__struct.html#a0016052943bb72880d3e54cc46ca0073',1,'ssh_callbacks_struct']]],
  ['channel_5fopen_5frequest_5fsession_5ffunction_16',['channel_open_request_session_function',['../structssh__server__callbacks__struct.html#a7ce22f98bbddd51bc53a788970248f57',1,'ssh_server_callbacks_struct']]],
  ['channel_5fopen_5frequest_5fx11_5ffunction_17',['channel_open_request_x11_function',['../structssh__callbacks__struct.html#a66ede60538c6615c221ea60e756b064c',1,'ssh_callbacks_struct']]],
  ['channel_5fpty_5frequest_5ffunction_18',['channel_pty_request_function',['../structssh__channel__callbacks__struct.html#ac3a287dbf7e2ef471b5b661f3ba7ac04',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fpty_5fwindow_5fchange_5ffunction_19',['channel_pty_window_change_function',['../structssh__channel__callbacks__struct.html#a92093666d23d03e9d8d0165180577ab9',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fread_5fbuffer_20',['channel_read_buffer',['../group__libssh__channel.html#gab391f5c978cb1bc8df3ebd061f38e8c5',1,'channel_read_buffer(ssh_channel channel, ssh_buffer buffer, uint32_t count, int is_stderr):&#160;channels.c'],['../group__libssh__channel.html#gab391f5c978cb1bc8df3ebd061f38e8c5',1,'channel_read_buffer(ssh_channel channel, ssh_buffer buffer, uint32_t count, int is_stderr):&#160;channels.c']]],
  ['channel_5fshell_5frequest_5ffunction_21',['channel_shell_request_function',['../structssh__channel__callbacks__struct.html#a347b5b7db57e74071bae5b1d8fe67b72',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fsignal_5ffunction_22',['channel_signal_function',['../structssh__channel__callbacks__struct.html#aef9c313bf3743cc236705a37ac86ff73',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fsubsystem_5frequest_5ffunction_23',['channel_subsystem_request_function',['../structssh__channel__callbacks__struct.html#a79a01697087dca3a828772a46c6ebb7a',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fwrite_5fwontblock_5ffunction_24',['channel_write_wontblock_function',['../structssh__channel__callbacks__struct.html#a1e8a2b155fe4ab0a745556583db7dac9',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fx11_5freq_5ffunction_25',['channel_x11_req_function',['../structssh__channel__callbacks__struct.html#a2be92a3baf149f1bb057b0abfa718c6d',1,'ssh_channel_callbacks_struct']]],
  ['chapter_201_3a_20a_20typical_20ssh_20session_26',['Chapter 1: A typical SSH session',['../libssh_tutor_guided_tour.html',1,'libssh_tutorial']]],
  ['chapter_202_3a_20a_20deeper_20insight_20on_20authentication_27',['Chapter 2: A deeper insight on authentication',['../libssh_tutor_authentication.html',1,'libssh_tutorial']]],
  ['chapter_203_3a_20opening_20a_20remote_20shell_28',['Chapter 3: Opening a remote shell',['../libssh_tutor_shell.html',1,'libssh_tutorial']]],
  ['chapter_204_3a_20passing_20a_20remote_20command_29',['Chapter 4: Passing a remote command',['../libssh_tutor_command.html',1,'libssh_tutorial']]],
  ['chapter_205_3a_20the_20sftp_20subsystem_30',['Chapter 5: The SFTP subsystem',['../libssh_tutor_sftp.html',1,'libssh_tutorial']]],
  ['chapter_206_3a_20the_20scp_20subsystem_31',['Chapter 6: The SCP subsystem',['../libssh_tutor_scp.html',1,'libssh_tutorial']]],
  ['chapter_207_3a_20forwarding_20connections_20tunnel_32',['Chapter 7: Forwarding connections (tunnel)',['../libssh_tutor_forwarding.html',1,'libssh_tutorial']]],
  ['chapter_208_3a_20threads_20with_20libssh_33',['Chapter 8: Threads with libssh',['../libssh_tutor_threads.html',1,'libssh_tutorial']]],
  ['chapter_209_3a_20authentication_20using_20pkcs_2011_20uris_34',['Chapter 9: Authentication using PKCS #11 URIs',['../libssh_tutor_pkcs11.html',1,'']]],
  ['ci_20instance_35',['Install a FreeBSD CI instance',['../md_README_8gitlab_8freebsd.html',1,'']]],
  ['close_36',['close',['../classssh_1_1Channel.html#a383618db99c0ccd5c33b5e7bcd992e80',1,'ssh::Channel']]],
  ['closing_20a_20channel_37',['Opening and closing a channel',['../libssh_tutor_shell.html#open_channel',1,'']]],
  ['closing_20a_20scp_20session_38',['Opening and closing a SCP session',['../libssh_tutor_scp.html#scp_session',1,'']]],
  ['closing_20a_20sftp_20session_39',['Opening and closing a SFTP session',['../libssh_tutor_sftp.html#sftp_session',1,'']]],
  ['command_40',['command',['../libssh_tutor_command.html',1,'Chapter 4: Passing a remote command'],['../libssh_tutor_command.html#exec_remote',1,'Executing a remote command'],['../libssh_tutor_command.html#remote_command',1,'Passing a remote command']]],
  ['computer_41',['computer',['../libssh_tutor_sftp.html#sftp_write',1,'Copying a file to the remote computer'],['../libssh_tutor_shell.html#read_data',1,'Displaying the data sent by the remote computer'],['../libssh_tutor_sftp.html#sftp_read',1,'Reading a file from the remote computer'],['../libssh_tutor_shell.html#write_data',1,'Sending user input to the remote computer']]],
  ['connect_42',['connect',['../classssh_1_1Session.html#a6d0498cf7e029e6beadb8b5f591ec472',1,'ssh::Session']]],
  ['connect_5fstatus_5ffunction_43',['connect_status_function',['../structssh__callbacks__struct.html#adc74777decb2f20ba522f794a29995ad',1,'ssh_callbacks_struct']]],
  ['connected_44',['connected',['../structssh__socket__callbacks__struct.html#a905f6e0260fd5891d4afa9ed229b8479',1,'ssh_socket_callbacks_struct']]],
  ['connecting_20to_20the_20server_45',['Connecting to the server',['../libssh_tutor_guided_tour.html#connect',1,'']]],
  ['connections_46',['Forwarding connections',['../libssh_tutor_forwarding.html#forwarding_connections',1,'']]],
  ['connections_20tunnel_47',['Chapter 7: Forwarding connections (tunnel)',['../libssh_tutor_forwarding.html',1,'libssh_tutorial']]],
  ['contents_20of_20a_20directory_48',['Listing the contents of a directory',['../libssh_tutor_sftp.html#sftp_ls',1,'']]],
  ['controlflow_49',['controlflow',['../structssh__socket__callbacks__struct.html#aad1bb53264cd71badae09bd3a0f561eb',1,'ssh_socket_callbacks_struct']]],
  ['copying_20a_20file_20to_20the_20remote_20computer_50',['Copying a file to the remote computer',['../libssh_tutor_sftp.html#sftp_write',1,'']]],
  ['copying_20full_20directory_20trees_20to_20the_20remote_20server_51',['Copying full directory trees to the remote server',['../libssh_tutor_scp.html#scp_recursive_write',1,'']]],
  ['copyright_20policy_52',['Copyright Policy',['../index.html#main-copyright',1,'']]],
  ['creating_20a_20directory_53',['Creating a directory',['../libssh_tutor_sftp.html#sftp_mkdir',1,'']]],
  ['creating_20files_20and_20directories_54',['Creating files and directories',['../libssh_tutor_scp.html#scp_write',1,'']]],
  ['creating_20the_20session_20and_20setting_20options_55',['Creating the session and setting options',['../libssh_tutor_guided_tour.html#setup',1,'']]]
];

==> libssh-docs-0.10.6-2-aarch64.pkg.tar.xz: usr/share/doc/libssh/html/search/all_b.js <==
var searchData=
[
  ['c_20wrapper_0',['C wrapper',['../group__ssh__cpp.html',1,'The libssh C++ wrapper'],['../libssh_tutor_todo.html#cpp',1,'The libssh C++ wrapper']]],
  ['callbacks_1',['callbacks',['../structssh__packet__callbacks__struct.html#a7a8584b3767b61599429dbb00b414c8e',1,'ssh_packet_callbacks_struct::callbacks'],['../group__libssh__callbacks.html',1,'The libssh callbacks']]],
  ['chacha20_5fpoly1305_5fkeysched_2',['chacha20_poly1305_keysched',['../structchacha20__poly1305__keysched.html',1,'']]],
  ['chacha_5fctx_3',['chacha_ctx',['../structchacha__ctx.html',1,'']]],
  ['changeptysize_4',['changePtySize',['../classssh_1_1Channel.html#a3adc48275cf34d211fb18514288f7c6f',1,'ssh::Channel']]],
  ['channel_5',['Channel',['../classssh_1_1Channel.html',1,'ssh::Channel'],['../libssh_tutor_shell.html#open_channel',1,'Opening and closing a channel']]],
  ['channel_20functions_6',['The SSH channel functions',['../group__libssh__channel.html',1,'']]],
  ['channel_5fauth_5fagent_5freq_5ffunction_7',['channel_auth_agent_req_function',['../structssh__channel__callbacks__struct.html#a9790a831ce74bafb52c710bff5f28b7b',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fclose_5ffunction_8',['channel_close_function',['../structssh__channel__callbacks__struct.html#af4801e862d6c0dba76e768e85a5acd9f',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fdata_5ffunction_9',['channel_data_function',['../structssh__channel__callbacks__struct.html#a12b38a7c3b2a38493c8d841015e7e8af',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fenv_5frequest_5ffunction_10',['channel_env_request_function',['../structssh__channel__callbacks__struct.html#a5db04c0739043d36b0fc3e014f9443a5',1,'ssh_channel_callbacks_struct']]],
  ['channel_5feof_5ffunction_11',['channel_eof_function',['../structssh__channel__callbacks__struct.html#a8405b740fbbe6c48cf4a7619f1844f0d',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fexec_5frequest_5ffunction_12',['channel_exec_request_function',['../structssh__channel__callbacks__struct.html#af51c2c1fd2036141e6ca1eb7fdbcb204',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fexit_5fsignal_5ffunction_13',['channel_exit_signal_function',['../structssh__channel__callbacks__struct.html#a9da535ec706641613e8fad0ecd974da9',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fexit_5fstatus_5ffunction_14',['channel_exit_status_function',['../structssh__channel__callbacks__struct.html#a2f5987f047f0f03b63e3759f5edaa80f',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fopen_5frequest_5fauth_5fagent_5ffunction_15',['channel_open_request_auth_agent_function',['../structssh__callbacks__struct.html#a0016052943bb72880d3e54cc46ca0073',1,'ssh_callbacks_struct']]],
  ['channel_5fopen_5frequest_5fsession_5ffunction_16',['channel_open_request_session_function',['../structssh__server__callbacks__struct.html#a7ce22f98bbddd51bc53a788970248f57',1,'ssh_server_callbacks_struct']]],
  ['channel_5fopen_5frequest_5fx11_5ffunction_17',['channel_open_request_x11_function',['../structssh__callbacks__struct.html#a66ede60538c6615c221ea60e756b064c',1,'ssh_callbacks_struct']]],
  ['channel_5fpty_5frequest_5ffunction_18',['channel_pty_request_function',['../structssh__channel__callbacks__struct.html#ac3a287dbf7e2ef471b5b661f3ba7ac04',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fpty_5fwindow_5fchange_5ffunction_19',['channel_pty_window_change_function',['../structssh__channel__callbacks__struct.html#a92093666d23d03e9d8d0165180577ab9',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fread_5fbuffer_20',['channel_read_buffer',['../group__libssh__channel.html#gab391f5c978cb1bc8df3ebd061f38e8c5',1,'channel_read_buffer(ssh_channel channel, ssh_buffer buffer, uint32_t count, int is_stderr):&#160;channels.c'],['../group__libssh__channel.html#gab391f5c978cb1bc8df3ebd061f38e8c5',1,'channel_read_buffer(ssh_channel channel, ssh_buffer buffer, uint32_t count, int is_stderr):&#160;channels.c']]],
  ['channel_5fshell_5frequest_5ffunction_21',['channel_shell_request_function',['../structssh__channel__callbacks__struct.html#a347b5b7db57e74071bae5b1d8fe67b72',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fsignal_5ffunction_22',['channel_signal_function',['../structssh__channel__callbacks__struct.html#aef9c313bf3743cc236705a37ac86ff73',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fsubsystem_5frequest_5ffunction_23',['channel_subsystem_request_function',['../structssh__channel__callbacks__struct.html#a79a01697087dca3a828772a46c6ebb7a',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fwrite_5fwontblock_5ffunction_24',['channel_write_wontblock_function',['../structssh__channel__callbacks__struct.html#a1e8a2b155fe4ab0a745556583db7dac9',1,'ssh_channel_callbacks_struct']]],
  ['channel_5fx11_5freq_5ffunction_25',['channel_x11_req_function',['../structssh__channel__callbacks__struct.html#a2be92a3baf149f1bb057b0abfa718c6d',1,'ssh_channel_callbacks_struct']]],
  ['chapter_201_3a_20a_20typical_20ssh_20session_26',['Chapter 1: A typical SSH session',['../libssh_tutor_guided_tour.html',1,'libssh_tutorial']]],
  ['chapter_202_3a_20a_20deeper_20insight_20on_20authentication_27',['Chapter 2: A deeper insight on authentication',['../libssh_tutor_authentication.html',1,'libssh_tutorial']]],
  ['chapter_203_3a_20opening_20a_20remote_20shell_28',['Chapter 3: Opening a remote shell',['../libssh_tutor_shell.html',1,'libssh_tutorial']]],
  ['chapter_204_3a_20passing_20a_20remote_20command_29',['Chapter 4: Passing a remote command',['../libssh_tutor_command.html',1,'libssh_tutorial']]],
  ['chapter_205_3a_20the_20sftp_20subsystem_30',['Chapter 5: The SFTP subsystem',['../libssh_tutor_sftp.html',1,'libssh_tutorial']]],
  ['chapter_206_3a_20the_20scp_20subsystem_31',['Chapter 6: The SCP subsystem',['../libssh_tutor_scp.html',1,'libssh_tutorial']]],
  ['chapter_207_3a_20forwarding_20connections_20tunnel_32',['Chapter 7: Forwarding connections (tunnel)',['../libssh_tutor_forwarding.html',1,'libssh_tutorial']]],
  ['chapter_208_3a_20threads_20with_20libssh_33',['Chapter 8: Threads with libssh',['../libssh_tutor_threads.html',1,'libssh_tutorial']]],
  ['chapter_209_3a_20authentication_20using_20pkcs_2011_20uris_34',['Chapter 9: Authentication using PKCS #11 URIs',['../libssh_tutor_pkcs11.html',1,'']]],
  ['ci_20instance_35',['Install a FreeBSD CI instance',['../md_README_8gitlab_8freebsd.html',1,'']]],
  ['close_36',['close',['../classssh_1_1Channel.html#a383618db99c0ccd5c33b5e7bcd992e80',1,'ssh::Channel']]],
  ['closing_20a_20channel_37',['Opening and closing a channel',['../libssh_tutor_shell.html#open_channel',1,'']]],
  ['closing_20a_20scp_20session_38',['Opening and closing a SCP session',['../libssh_tutor_scp.html#scp_session',1,'']]],
  ['closing_20a_20sftp_20session_39',['Opening and closing a SFTP session',['../libssh_tutor_sftp.html#sftp_session',1,'']]],
  ['command_40',['Chapter 4: Passing a remote command',['../libssh_tutor_command.html',1,'libssh_tutorial']]],
  ['command_41',['Command',['../libssh_tutor_command.html#exec_remote',1,'Executing a remote command'],['../libssh_tutor_command.html#remote_command',1,'Passing a remote command']]],
  ['computer_42',['Computer',['../libssh_tutor_sftp.html#sftp_write',1,'Copying a file to the remote computer'],['../libssh_tutor_shell.html#read_data',1,'Displaying the data sent by the remote computer'],['../libssh_tutor_sftp.html#sftp_read',1,'Reading a file from the remote computer'],['../libssh_tutor_shell.html#write_data',1,'Sending user input to the remote computer']]],
  ['connect_43',['connect',['../classssh_1_1Session.html#a6d0498cf7e029e6beadb8b5f591ec472',1,'ssh::Session']]],
  ['connect_5fstatus_5ffunction_44',['connect_status_function',['../structssh__callbacks__struct.html#adc74777decb2f20ba522f794a29995ad',1,'ssh_callbacks_struct']]],
  ['connected_45',['connected',['../structssh__socket__callbacks__struct.html#a905f6e0260fd5891d4afa9ed229b8479',1,'ssh_socket_callbacks_struct']]],
  ['connecting_20to_20the_20server_46',['Connecting to the server',['../libssh_tutor_guided_tour.html#connect',1,'']]],
  ['connections_47',['Forwarding connections',['../libssh_tutor_forwarding.html#forwarding_connections',1,'']]],
  ['connections_20tunnel_48',['Chapter 7: Forwarding connections (tunnel)',['../libssh_tutor_forwarding.html',1,'libssh_tutorial']]],
  ['contents_20of_20a_20directory_49',['Listing the contents of a directory',['../libssh_tutor_sftp.html#sftp_ls',1,'']]],
  ['controlflow_50',['controlflow',['../structssh__socket__callbacks__struct.html#aad1bb53264cd71badae09bd3a0f561eb',1,'ssh_socket_callbacks_struct']]],
  ['copying_20a_20file_20to_20the_20remote_20computer_51',['Copying a file to the remote computer',['../libssh_tutor_sftp.html#sftp_write',1,'']]],
  ['copying_20full_20directory_20trees_20to_20the_20remote_20server_52',['Copying full directory trees to the remote server',['../libssh_tutor_scp.html#scp_recursive_write',1,'']]],
  ['copyright_20policy_53',['Copyright Policy',['../index.html#main-copyright',1,'']]],
  ['creating_20a_20directory_54',['Creating a directory',['../libssh_tutor_sftp.html#sftp_mkdir',1,'']]],
  ['creating_20files_20and_20directories_55',['Creating files and directories',['../libssh_tutor_scp.html#scp_write',1,'']]],
  ['creating_20the_20session_20and_20setting_20options_56',['Creating the session and setting options',['../libssh_tutor_guided_tour.html#setup',1,'']]]
];
